# Chana: An NLP toolkit for the Shipibo-Konibo language of Peru.

chana is a Python library of various NLP tools for the Shipibo-Konibo. 
Some of these tools can be reused on other peruvian indigenous and/or highly agglutinative languages. 
It is built on top of scikit-learn, python-crfsuite and distributed under MIT license.

Chana has various NLP tools such as:

* Lemmatizer.
* Part-of-Speech tagger. 
* Named Entity annotation.
* Syllabificator.


## Installation

### Dependencies

Chana requires:

- Python (>= 3.4)
- NumPy (>= 1.13.1)
- Scikit-learn (>= 0.18.1)
- Python-crfsuite (>= 0.9.5)


### User installation

If you already have a working installation of numpy, scikit-learn and python-crfsuite,
the easiest way to install chana is using ``pip`` :

```
pip install chana
```


## Help and Support

### Important links

- Project website: http://chana.inf.pucp.edu.pe
- Official source code repo: https://github.com/iapucp/chana-library
- Download releases: https://pypi.python.org/pypi/...
- HTML documentation (stable release): http://chana.readthedocs.io/en/latest/

### Communication

- Website: http://chana.inf.pucp.edu.pe
- Authors: **Jose Pereira** - [jpereiran](https://github.com/jpereiran)


### Contact

For any question and feedback please contact:

- José Pereira Noriega (jpereira@pucp.edu.pe)
- Rodolfo Mercado Gonzales (rmercado@pucp.edu.pe)
- Arturo Oncevay Marcos (arturo.oncevay@pucp.edu.pe)
- Vivian Góngora Patrón (v.gongora@pucp.pe)

### Acknowledgments

- Pontificia Universidad Católica del Perú (PUCP) 
- Consejo Nacional de Ciencia, Tecnología e Innovación Tecnológica (CONCYTEC)
- NVIDIA
- Amazon Web Services

